@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: warp-tls
 version: 3.2.1
-id: warp-tls-3.2.1-4d202b26f63cb34cdcb258e59f591b80
-key: warpt_GEIfLMd2B7m4VsBbKlskkZ
+id: warp-tls-3.2.1-c7d9bd34a782025436332ad1a7746929
+key: warpt_1RYAhSbD90CApj1cr1iupg
 license: MIT
 maintainer: michael@snoyman.com
 stability: Stable
@@ -23,7 +23,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/warp-tls-3.2.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/warp-tls-3.2.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/warp-tls-3.2.1
-hs-libraries: HSwarp-tls-3.2.1-GEIfLMd2B7m4VsBbKlskkZ
+hs-libraries: HSwarp-tls-3.2.1-1RYAhSbD90CApj1cr1iupg
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
@@ -32,7 +32,7 @@ depends:
     streaming-commons-0.1.15.2-092d722155f2dc7f0b2e7a0dc037f30c
     tls-1.3.4-c1ffd726a31a364e53d7dbf7360c4f21
     wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
-    warp-3.2.3-e779983be81de2d2755ab5db7108dace
+    warp-3.2.3-b193a405602f21fe67837dcb996939ee
 haddock-interfaces: /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
 haddock-html: /usr/share/doc/haskell-warp-tls/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
